==> haskell-witch-1.2.0.2-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-witch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witch
version:              1.2.0.2
visibility:           public
id:                   witch-1.2.0.2-DlAAOWaBOhg9ay5oi7TdYY
key:                  witch-1.2.0.2-DlAAOWaBOhg9ay5oi7TdYY
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Convert values from one type into another.
description:          Witch converts values from one type into another.
category:             Data
abi:                  51b75085f30f6eae788ca7f23787e471
exposed:              True
exposed-modules:
    Witch Witch.Encoding Witch.From Witch.Instances Witch.Lift
    Witch.TryFrom Witch.TryFromException Witch.Utility

import-dirs:          /usr/lib/ghc-9.6.6/site-local/witch-1.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/witch-1.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/witch-1.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witch
hs-libraries:         HSwitch-1.2.0.2-DlAAOWaBOhg9ay5oi7TdYY
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-witch/html/witch.haddock
haddock-html:         /usr/share/doc/haskell-witch/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-witch-1.2.0.2-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-witch.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witch
version:              1.2.0.2
visibility:           public
id:                   witch-1.2.0.2-KCfdEZJcUXX5HXuiPv5Ol1
key:                  witch-1.2.0.2-KCfdEZJcUXX5HXuiPv5Ol1
license:              MIT
maintainer:           Taylor Fausak
synopsis:             Convert values from one type into another.
description:          Witch converts values from one type into another.
category:             Data
abi:                  bb59830b4ebf4b8fdca4157a502e62a8
exposed:              True
exposed-modules:
    Witch Witch.Encoding Witch.From Witch.Instances Witch.Lift
    Witch.TryFrom Witch.TryFromException Witch.Utility

import-dirs:          /usr/lib/ghc-9.6.6/site-local/witch-1.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/witch-1.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/witch-1.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witch
hs-libraries:         HSwitch-1.2.0.2-KCfdEZJcUXX5HXuiPv5Ol1
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-witch/html/witch.haddock
haddock-html:         /usr/share/doc/haskell-witch/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
